Swift client generation.
Generates the caller protocol and client implementation for making application-level RPC calls. Each generated client method represents one logical call; the runtime may realize that call with one request attempt or multiple request attempts if retry/session recovery creates later attempts for the same operation.
Functions
- generate_
client - Generate complete client code (caller protocol + client implementation).