Swift schema generation for wire schema exchange.
Generates runtime schema information for protocol wire schema exchange
using the canonical Schema/SchemaKind/TypeRef representation.
Type-level channel binding is driven by the same schema registry.
Functions
- generate_
schemas - Generate schema code (wire schemas only — binding uses the same registry).